import Vue from 'vue'

export default class DialogService {
    constructor(component, options) {

        options.visible = options.visible || false;

        this.options = options;
        let Content = Vue.extend(component);
        Content.prototype.$dialog = this;
        let Dialog = Vue.extend({
            render: (h) => {
                return h('el-dialog', {
                    props: {
                        ...options
                    },
                    style: options.style,
                    on: {
                        close: () => { this._close();},
                        open: options.open || (() => {}),
                        'visible-change': visible => {
                            if (!visible) {
                                this._close();
                            }
                        }
                    }
                }, [
                    h(Content, {props: {...options}})
                ])
            }
        });
        this.dialog = new Dialog();
        this.dialogEl = this.dialog.$mount().$el;
        document.querySelector('body').appendChild(this.dialogEl);
        return this;
    }
    open() {
        this.options.visible = true;
        this.dialog.$forceUpdate();
    };
    close() {
        this._close();
        this.options.close && this.options.close.apply(null, [...arguments]);
    };
    _close () {
      this.options.visible = false;
      this.dialog.$forceUpdate();
      if (this.options.destroyedOnClose) {
        this.destroy();
      }
    }
    destroy() {
        try {
            document.querySelector('body').removeChild(this.dialogEl);
        } catch (e) {

        }
    }
}
